package perlsecret;
use strict;    # make CPANTS happy
our $VERSION = '1.005';
0;    # no point in loading this module
